"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _type = require("./type");

function _default(types) {
  return {
    ImportDeclaration(path, state) {
      const {
        node
      } = path;
      if (!node) return;
      if (!types.isImportDeclaration(node)) return;
      const opts = state.opts || {}; // 获取配置

      const {
        specifiers,
        source
      } = node;
      const {
        value
      } = source; // 获取模块名称

      const components = opts.components; // 获取配置项目
      // components配置项必须存在

      if (!components) {
        console.warn('Components configuration must exist');
        return;
      } // components配置项必须是object类型


      if (!(0, _type.isObject)(components)) {
        console.warn('The type of components configuration must be object type.');
        return;
      } // 获取键值


      const componentValue = components[value];
      if (!componentValue) return;

      if (!(0, _type.isString)(componentValue)) {
        console.warn('The key value in components must be string type.');
        return;
      } // 插入模块


      let stringLiteralValue = componentValue; // 约定以~开头的路径，不添加moduleName

      if (stringLiteralValue[0] !== '~') {
        stringLiteralValue = `${value}/${componentValue}`;
      } else {
        stringLiteralValue = stringLiteralValue.substr(1);
      }

      const stringLiteral = types.stringLiteral(stringLiteralValue);
      const importDeclaration = types.importDeclaration([], stringLiteral);
      path.insertAfter([importDeclaration]);
    }

  };
}